==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>设备正在使用</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名字</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>被使用</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>邮寄最后一个视频</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>邮寄一个或多个选取的视频</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>发送</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>请安装视频播放器</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>您会看到视频作为附件</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>选取一个或多个文件</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>窗口边框</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>全屏显示</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>右键菜单</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>用户自定义</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>设备正在使用</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名字</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>被使用</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation>双击最大化</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>全屏模式</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>区域</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认值</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>编码器</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>不要录制鼠标</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>视频路径</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>播放器</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>开始录制时最小化Vokoscreen</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>发送</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>录制时间</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>大小(KB)</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>录制屏幕大小</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>设定帧率</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>打开目录</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>倒计时</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>播放最后一个视频</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>发送视频</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>选取一个或多个装置</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>实际的帧率</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>网站</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>支持</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>开发者</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>帧率</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐赠</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>开发日志</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>翻译</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>源码</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>任务栏显示</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>采集器</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>新版可用</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>视频编码</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>音频编码</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>摄像头</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>选择摄像头</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>镜面</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>显示</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>显示所有</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>开发者网站</translation>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>设备正在使用</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名字</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>使用者</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation>显示单击设置</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>邮寄最后一个视频</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>邮寄一个或多个选取的视频</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>发送</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>请安装视频播放器</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>您会看到视频作为附件</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>选取一个或多个文件</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>窗口边框</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>全屏显示</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>右键菜单</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>用户自定义</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>设备正在使用</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名字</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>使用者</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation>双击最大化</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>全屏模式</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>区域</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认值</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>编码器</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>不要录制鼠标</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>视频路径</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>播放器</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>开始录制时最小化Vokoscreen</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>发送</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>录制时间</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>大小(KB)</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>录制屏幕大小</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>设定帧率</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>打开目录</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>倒计时</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>播放最后一个视频</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>发送视频</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>选取一个或多个设备</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>实际的帧率</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>网站</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>支持</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>开发者</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>帧率</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐赠</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>翻译</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>源码</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>系统托盘显示</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>新版可用</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>视频编码</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>音频编码</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>摄像头</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>选择摄像头</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>镜面</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>显示</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>显示所有</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>开发者网站</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>采集器</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>选择采集器</translation>
    </message>
    <message>
        <source>Hide window</source>
        <translation>隐藏窗口</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Show window</source>
        <translation>显示窗口</translation>
    </message>
    <message>
        <source>Lossless</source>
        <translation>无损</translation>
    </message>
</context>
</TS>
